km3pipe\.dataclasses\.TrackSeries
=================================

.. currentmodule:: km3pipe.dataclasses

.. autoclass:: TrackSeries

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TrackSeries.__init__
      ~TrackSeries.conv_from
      ~TrackSeries.conv_to
      ~TrackSeries.deserialise
      ~TrackSeries.from_aanet
      ~TrackSeries.from_arrays
      ~TrackSeries.from_km3df
      ~TrackSeries.from_table
      ~TrackSeries.get_len
      ~TrackSeries.get_usr_item
      ~TrackSeries.get_usr_name
      ~TrackSeries.next
      ~TrackSeries.serialise
   
   

   
   
   